pub struct EncryptionDetails {
pub standard: Standard,
pub initialization_vector: String,
pub key: String,
}Expand description
EncryptionDetails : Encryption details for required client-side encryption and decryption of document contents.
Fields
standard: StandardThe encryption standard required to encrypt or decrypt the document contents.
initialization_vector: StringThe vector to encrypt or decrypt the document contents using Cipher Block Chaining (CBC).
key: StringThe encryption key used to encrypt or decrypt the document contents.
Implementations